==> mcss-0.0.39.tar.gz: mcss-0.0.39/python/setup.py <==
# -*- coding: utf-8 -*-

import os, sys, re
from os.path import join as pj
from setuptools import setup, find_packages, Extension
from distutils.sysconfig import get_python_lib
from shutil import rmtree

name = "mcss"
packagename = "mcss"
version = "0.0.39"
description = "multicompartment stochastic simulator"
long_description = "Python API for multicompartment stochastic simulator (mcss)"
authors = "Jamie Twycross",
author_email = "jpt@cs.nott.ac.uk"
url = "http://cs.nott.ac.uk/~jpt"
license = "GNU GPL version 3"

def split_args(s):
	return re.split("\s+", s.strip())

def is_system_wide_install():
	return os.access(get_python_lib(), os.W_OK)

def get_root():
	try:
		return sys.argv[sys.argv.index("--root") + 1]
	except ValueError:
		return ""

def pre_install():
	if not is_system_wide_install():
		sys.argv.extend(["--prefix", "/usr/local"])

def uninstall():
	if is_system_wide_install():
		prefix = None
	else:
		prefix = "/usr/local"
	egg_name = "%s-%s-py%s.egg" % (packagename,"*",sys.version[:3])
	file = get_root() + "/" + get_python_lib(prefix=prefix) + "/" + egg_name
	rmtree(file, ignore_errors=True)
	sys.exit(0)

commands = {
	"install": pre_install,
	"uninstall": uninstall,
	}

setup(
	name=name,
	version=version,
	author=authors,
	author_email=author_email,
	description=description,
	long_description=long_description,
	url=url,
	license=license,
	packages=[packagename],
	include_package_data=True,
	package_data={packagename : ['*.pyd', '*.so', '*.dylib'],},
	zip_safe=False,
	ext_package=packagename,
	ext_modules=[
		Extension(
			'Psystem',
			['src/export_Psystem.cpp'],
			depends=['src/export_Psystem.h'],
			extra_compile_args=split_args("-I.. -I..  -pthread -I/usr/local/include -I/usr/include/sigc++-2.0 -I/usr/lib/sigc++-2.0/include -I/usr/include/libxml++-2.6 -I/usr/lib/libxml++-2.6/include -I/usr/include/muParser -I/usr/include/libxml2 -I/usr/include/glibmm-2.4 -I/usr/lib/glibmm-2.4/include -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include   -DH5_NO_DEPRECATED_SYMBOLS -I/usr/include/libxml2    "),
			library_dirs=split_args("../mcss/.libs"),
			extra_link_args=split_args("-lmcss -lpthread -lhdf5  -pthread -L/usr/local/lib -lecsb -lxml++-2.6 -lgsl -lgslcblas -lm -lmuparser -lxml2 -lglibmm-2.4 -lgobject-2.0 -lsigc-2.0 -lgthread-2.0 -lrt -lglib-2.0   -lz -lbz2 -lsbml -lstdc++ -lm -lxml2    "),
		),
		Extension(
			'SimulationParameters',
			['src/export_SimulationParameters.cpp'],
			depends=['src/export_SimulationParameters.h'],
			extra_compile_args=split_args("-I.. -I..  -pthread -I/usr/local/include -I/usr/include/sigc++-2.0 -I/usr/lib/sigc++-2.0/include -I/usr/include/libxml++-2.6 -I/usr/lib/libxml++-2.6/include -I/usr/include/muParser -I/usr/include/libxml2 -I/usr/include/glibmm-2.4 -I/usr/lib/glibmm-2.4/include -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include   -DH5_NO_DEPRECATED_SYMBOLS -I/usr/include/libxml2    "),
			library_dirs=split_args("../mcss/.libs"),
			extra_link_args=split_args("-lmcss -lpthread -lhdf5  -pthread -L/usr/local/lib -lecsb -lxml++-2.6 -lgsl -lgslcblas -lm -lmuparser -lxml2 -lglibmm-2.4 -lgobject-2.0 -lsigc-2.0 -lgthread-2.0 -lrt -lglib-2.0   -lz -lbz2 -lsbml -lstdc++ -lm -lxml2    "),
		),
	]
	)

==> mcss-0.0.43.tar.gz: mcss-0.0.43/python/setup.py <==
# -*- coding: utf-8 -*-

import os, sys, re
from os.path import join as pj
from setuptools import setup, find_packages, Extension
from distutils.sysconfig import get_python_lib
from shutil import rmtree

name = "mcss"
packagename = "mcss"
version = "0.0.43"
description = "multicompartment stochastic simulator"
long_description = "Python API for multicompartment stochastic simulator (mcss)"
authors = "Jamie Twycross",
author_email = "jpt@cs.nott.ac.uk"
url = "http://cs.nott.ac.uk/~jpt"
license = "GNU GPL version 3"

def split_args(s):
	return re.split("\s+", s.strip())

def is_system_wide_install():
	return os.access(get_python_lib(), os.W_OK)

def get_root():
	try:
		return sys.argv[sys.argv.index("--root") + 1]
	except ValueError:
		return ""

def pre_install():
	if not is_system_wide_install():
		sys.argv.extend(["--prefix", "/usr/local"])

def uninstall():
	if is_system_wide_install():
		prefix = None
	else:
		prefix = "/usr/local"
	egg_name = "%s-%s-py%s.egg" % (packagename,"*",sys.version[:3])
	file = get_root() + "/" + get_python_lib(prefix=prefix) + "/" + egg_name
	rmtree(file, ignore_errors=True)
	sys.exit(0)

commands = {
	"install": pre_install,
	"uninstall": uninstall,
	}

setup(
	name=name,
	version=version,
	author=authors,
	author_email=author_email,
	description=description,
	long_description=long_description,
	url=url,
	license=license,
	packages=[packagename],
	include_package_data=True,
	package_data={packagename : ['*.pyd', '*.so', '*.dylib'],},
	zip_safe=False,
	ext_package=packagename,
	ext_modules=[
		Extension(
			'Psystem',
			['src/export_Psystem.cpp'],
			depends=['src/export_Psystem.h'],
			extra_compile_args=split_args("-I.. -I..  -pthread -I/usr/local/include -I/usr/include/sigc++-2.0 -I/usr/lib/sigc++-2.0/include -I/usr/include/libxml++-2.6 -I/usr/lib/libxml++-2.6/include -I/usr/include/muParser -I/usr/include/libxml2 -I/usr/include/glibmm-2.4 -I/usr/lib/glibmm-2.4/include -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include   -DH5_NO_DEPRECATED_SYMBOLS -I/usr/include/libxml2    "),
			library_dirs=split_args("../mcss/.libs"),
			extra_link_args=split_args("-lmcss -ldl -lpthread -lhdf5  -pthread -L/usr/local/lib -lecsb -lxml++-2.6 -lgsl -lgslcblas -lm -lmuparser -lxml2 -lglibmm-2.4 -lgobject-2.0 -lsigc-2.0 -lgthread-2.0 -lrt -lglib-2.0   -lz -lbz2 -lsbml -lstdc++ -lm -lxml2    "),
		),
		Extension(
			'SimulationParameters',
			['src/export_SimulationParameters.cpp'],
			depends=['src/export_SimulationParameters.h'],
			extra_compile_args=split_args("-I.. -I..  -pthread -I/usr/local/include -I/usr/include/sigc++-2.0 -I/usr/lib/sigc++-2.0/include -I/usr/include/libxml++-2.6 -I/usr/lib/libxml++-2.6/include -I/usr/include/muParser -I/usr/include/libxml2 -I/usr/include/glibmm-2.4 -I/usr/lib/glibmm-2.4/include -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include   -DH5_NO_DEPRECATED_SYMBOLS -I/usr/include/libxml2    "),
			library_dirs=split_args("../mcss/.libs"),
			extra_link_args=split_args("-lmcss -ldl -lpthread -lhdf5  -pthread -L/usr/local/lib -lecsb -lxml++-2.6 -lgsl -lgslcblas -lm -lmuparser -lxml2 -lglibmm-2.4 -lgobject-2.0 -lsigc-2.0 -lgthread-2.0 -lrt -lglib-2.0   -lz -lbz2 -lsbml -lstdc++ -lm -lxml2    "),
		),
	]
	)
